@@ -64,6 +64,7 @@ from openstack import exceptions
 from openstack.identity import identity_service
 from openstack.image import image_service
 from openstack.key_manager import key_manager_service
+from openstack.load_balancer import load_balancer_service as lb_service
 from openstack.message import message_service
 from openstack import module_loader
 from openstack.network import network_service
@@ -102,6 +103,7 @@ class Profile(object):
         self._add_service(identity_service.IdentityService(version="v3"))
         self._add_service(image_service.ImageService(version="v2"))
         self._add_service(key_manager_service.KeyManagerService(version="v1"))
+        self._add_service(lb_service.LoadBalancerService(version="v2"))
         self._add_service(message_service.MessageService(version="v1"))
         self._add_service(network_service.NetworkService(version="v2"))
         self._add_service(
